@@ -56,7 +56,7 @@ def default_work_dir():
 
 def choose_mwc_username(default=None):
     """Asks the user to choose their MWC username."""
-    click.prompt(
+    return click.prompt(
         question("What is your MWC username?"),
         default=default
     )
